Package: metaConvert
Type: Package
Title: An Automatic Suite for Estimation of Various Effect Size
        Measures
Version: 2.0.0
Authors@R: c(
        person(given = c("Corentin", "J."), family= "Gosling",  role = c("aut", "cre"),
                email = "corentin.gosling@parisnanterre.fr"),
        person(given = "Samuele",
               family= "Cortese", role = "aut",
               email = "samuele.cortese@gmail.com"),
        person(given = "Marco",
               family= "Solmi", role = "aut",
               email = "marco.solmi83@gmail.com"),
        person(given = "Belen",
               family= "Haza", role = "aut",
               email = "hazabelen@gmail.com"),
        person(given = "Eduard",
               family= "Vieta", role = "aut",
               email = "EVIETA@clinic.cat"),
        person(given = "Richard",
               family= "Delorme", role = "aut",
               email = "richard.delorme.rdb@gmail.com"),
        person(given = "Paolo",
               family= "Fusar-Poli",  role = "aut",
               email = "Paolo.fusar-poli@kcl.ac.uk"),
        person(given = "Joaquim",
               family= "Radua",  role = "aut",
               email = "radua@clinic.cat"))
Maintainer: Corentin J. Gosling <corentin.gosling@parisnanterre.fr>
Description: Automatically estimate 14 effect size measures from a well-formatted dataset, including Cohen's d, Hedges' g, mean difference, odds ratio, risk ratio, incidence rate ratio, risk difference, number needed to treat, Pearson correlation, Fisher's z, Cronbach's alpha, intraclass correlation coefficient, and single-group proportion. Provides a two-tier quality-flag diagnostic system for input validation and post-computation plausibility checks, missing-data guidance that tells users which columns would unlock additional estimators, post-hoc correction for attenuation due to measurement error, and standalone psychometric utilities (standard error of measurement, smallest detectable change, change-score reliability). Various other functions can help, for example, removing dependency between several effect sizes, or identifying differences between two datasets.
    This package is mainly designed to assist in conducting a systematic review with a meta-analysis but can be useful to any researcher interested in estimating an effect size.
Imports: compareDF, metafor, estimraw, rio
License: GPL (>= 3)
Encoding: UTF-8
LazyData: true
Depends: R (>= 3.5.0)
Suggests: testthat (>= 3.0.0), metaumbrella, TOSTER, esc, epiR,
        compute.es, meta, effectsize, MetaUtility, MASS, mvtnorm,
        psych, psychmeta, knitr, DT, rmarkdown
Config/testthat/edition: 3
VignetteBuilder: knitr
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-07-20 14:45:15 UTC; coren
Author: Corentin J. Gosling [aut, cre],
  Samuele Cortese [aut],
  Marco Solmi [aut],
  Belen Haza [aut],
  Eduard Vieta [aut],
  Richard Delorme [aut],
  Paolo Fusar-Poli [aut],
  Joaquim Radua [aut]
Repository: CRAN
Date/Publication: 2026-07-20 20:00:02 UTC
