# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,metaConvert)
S3method(print,metaConvert)
S3method(summary,metaConvert)
export(aggregate_df)
export(compare_df)
export(compute_sdc)
export(compute_sem)
export(convert_df)
export(data_extraction_sheet)
export(es_disattenuate)
export(es_from_2x2)
export(es_from_2x2_prop)
export(es_from_2x2_sum)
export(es_from_ancova_f)
export(es_from_ancova_f_pval)
export(es_from_ancova_md_ci)
export(es_from_ancova_md_pval)
export(es_from_ancova_md_sd)
export(es_from_ancova_md_se)
export(es_from_ancova_means_ci)
export(es_from_ancova_means_sd)
export(es_from_ancova_means_sd_pooled_adj)
export(es_from_ancova_means_sd_pooled_crude)
export(es_from_ancova_means_se)
export(es_from_ancova_t)
export(es_from_ancova_t_pval)
export(es_from_anova_f)
export(es_from_anova_pval)
export(es_from_beta_std)
export(es_from_beta_unstd)
export(es_from_cases_time)
export(es_from_chisq)
export(es_from_chisq_pval)
export(es_from_cohen_d)
export(es_from_cohen_d_adj)
export(es_from_cronbach_alpha)
export(es_from_etasq)
export(es_from_etasq_adj)
export(es_from_fisher_z)
export(es_from_hedges_g)
export(es_from_icc)
export(es_from_linreg_b_ci)
export(es_from_linreg_b_pval)
export(es_from_linreg_b_se)
export(es_from_linreg_t)
export(es_from_logreg_t)
export(es_from_md_ci)
export(es_from_md_pval)
export(es_from_md_sd)
export(es_from_md_se)
export(es_from_mean_change_ci)
export(es_from_mean_change_ci_single_group)
export(es_from_mean_change_pval)
export(es_from_mean_change_pval_single_group)
export(es_from_mean_change_sd)
export(es_from_mean_change_sd_single_group)
export(es_from_mean_change_se)
export(es_from_mean_change_se_single_group)
export(es_from_means_ci)
export(es_from_means_ci_pre_post)
export(es_from_means_ci_pre_post_single_group)
export(es_from_means_sd)
export(es_from_means_sd_pooled)
export(es_from_means_sd_pre_post)
export(es_from_means_sd_pre_post_single_group)
export(es_from_means_se)
export(es_from_means_se_pre_post)
export(es_from_means_se_pre_post_single_group)
export(es_from_med_min_max)
export(es_from_med_min_max_quarts)
export(es_from_med_quarts)
export(es_from_or)
export(es_from_or_ci)
export(es_from_or_pval)
export(es_from_or_se)
export(es_from_paired_f)
export(es_from_paired_f_pval)
export(es_from_paired_t)
export(es_from_paired_t_pval)
export(es_from_paired_t_single_group)
export(es_from_pearson_r)
export(es_from_phi)
export(es_from_plot_ancova_means)
export(es_from_plot_means)
export(es_from_prop_single_group)
export(es_from_prop_single_group_counts)
export(es_from_pt_bis_r)
export(es_from_pt_bis_r_pval)
export(es_from_rd_ci)
export(es_from_rd_pval)
export(es_from_rd_se)
export(es_from_rr_ci)
export(es_from_rr_pval)
export(es_from_rr_se)
export(es_from_spearman_rho)
export(es_from_student_t)
export(es_from_student_t_pval)
export(es_from_user_adj)
export(es_from_user_crude)
export(es_variab_from_means_ci)
export(es_variab_from_means_sd)
export(es_variab_from_means_se)
export(pool_arms)
export(reliability_change_score)
export(see_input_data)
export(summary.metaConvert)
importFrom(stats,aggregate.data.frame)
importFrom(stats,df)
importFrom(stats,dnorm)
importFrom(stats,na.omit)
importFrom(stats,optimize)
importFrom(stats,pnorm)
importFrom(stats,pt)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,sd)
importFrom(utils,packageVersion)
