
<!-- README.md is generated from README.Rmd. Please edit that file -->

# metaConvert

[![Lifecycle:
experimental](https://img.shields.io/badge/lifecycle-experimental-orange.svg)](https://lifecycle.r-lib.org/articles/stages.html#experimental)
[![CRAN
status](https://www.r-pkg.org/badges/version/metaConvert)](https://CRAN.R-project.org/package=metaConvert)
[![License: GPL
(\>=3)](https://img.shields.io/badge/license-GPL%20%28%3E%3D3%29-red.svg)](https://www.gnu.org/licenses/gpl-3.0.html)
<br> [![Monthly
downloads](https://cranlogs.r-pkg.org/badges/metaConvert)](https://cran.r-project.org/package=metaConvert)
[![Total
downloads](https://cranlogs.r-pkg.org/badges/grand-total/metaConvert)](https://cran.r-project.org/package=metaConvert)

## Important

If you are not familiar with R, you can access the core features of this
package on your web browser on its dedicated website
[(https://metaConvert.org/)](https://metaConvert.org/).

## Introduction

This package automatically estimates 11 effect size measures from a
well-formatted dataset. Various other functions can help, for example,
removing dependency between several effect sizes, or identifying
differences between two datasets.

This package is mainly designed to assist in conducting a systematic
review with a meta-analysis but can be useful to any researcher
interested in estimating an effect size.

## Installation

You can install the released version of metaConvert from
[CRAN](https://CRAN.R-project.org) with:

``` r
install.packages("metaConvert")
```

## Citation

The metaConvert package was written by Corentin J Gosling, Samuele
Cortese, Marco Solmi, Belen Haza, Eduard Vieta, Richard Delorme, Paolo
Fusar-Poli and Joaquim Radua. It is licensed under the GNU General
Public License. <br>You can use metaConvert for free… but please cite
our work ;-) <br><br> <b>Citation:</b> <em>Gosling CJ, Cortese S, Solmi
M, Haza B, Vieta E, Delorme R, Fusar-Poli P, & Radua J. (2024).
metaConvert: An Automatic Suite for Estimation of 11 Different Effect
Size Measures and Flexible Conversion Across Them. R package version
1.0.0. <https://metaConvert.org/></em><br><br> To obtain a bibtex
version of this citation in R, type

``` r
citation(package = "metaConvert")
```
