% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/es_from_ANCOVA_means.R
\name{es_from_ancova_means_sd_pooled_adj}
\alias{es_from_ancova_means_sd_pooled_adj}
\title{Convert means and adjusted pooled standard deviation of two independent groups obtained from an ANCOVA model into several effect size measures}
\usage{
es_from_ancova_means_sd_pooled_adj(
  ancova_mean_exp,
  ancova_mean_nexp,
  ancova_mean_sd_pooled,
  cov_outcome_r,
  n_cov_ancova,
  n_exp,
  n_nexp,
  smd_to_cor = "viechtbauer",
  smd_var = "borenstein",
  reverse_ancova_means
)
}
\arguments{
\item{ancova_mean_exp}{adjusted mean of participants in the experimental/exposed group.}

\item{ancova_mean_nexp}{adjusted mean of participants in the non-experimental/non-exposed group.}

\item{ancova_mean_sd_pooled}{adjusted pooled standard deviation.}

\item{cov_outcome_r}{correlation between the outcome and covariate(s) (multiple correlation when multiple covariates are included in the ANCOVA model).}

\item{n_cov_ancova}{number of covariates in the ANCOVA model.}

\item{n_exp}{number of participants in the experimental/exposed group.}

\item{n_nexp}{number of participants in the non-experimental/non-exposed group.}

\item{smd_to_cor}{formula used to convert the adjusted \code{cohen_d} value into a coefficient correlation (see details).}

\item{smd_var}{name of the sampling-variance formula for the standardized mean difference: "borenstein" (default) or "hedges_olkin" (alias "viechtbauer"). The two differ by a squared small-sample-correction factor (J^2); "hedges_olkin" is a few percent larger at small samples.}

\item{reverse_ancova_means}{a logical value indicating whether the direction of the generated effect sizes should be flipped.}
}
\value{
This function estimates and converts between several effect size measures.

\tabular{ll}{
\code{natural effect size measure} \tab MD + D + G\cr
\tab \cr
\code{converted effect size measure} \tab OR + R + Z \cr
\tab \cr
\code{required input data} \tab See 'Section 19. Adjusted: Means and dispersion'\cr
\tab https://metaconvert.org/input.html\cr
\tab \cr
}
}
\description{
Convert means and adjusted pooled standard deviation of two independent groups obtained from an ANCOVA model into several effect size measures
}
\details{
This function converts the adjusted pooled standard deviations of two independent groups
into a crude pooled standard deviation.
and then relies on the calculations of the \code{\link{es_from_ancova_means_sd_pooled_crude}()} function.

\strong{To convert the adjusted pooled SD into a crude pooled SD} (table 12.3 in Cooper):
\deqn{mean\_sd\_pooled =  \frac{ancova\_mean\_sd\_pooled}{\sqrt{1 - cov\_outcome\_r^2}}}

Calculations of the \code{\link{es_from_ancova_means_sd_pooled_crude}()} are then applied.
}
\examples{
es_from_ancova_means_sd_pooled_adj(
  ancova_mean_exp = 98, ancova_mean_nexp = 87,
  ancova_mean_sd_pooled = 17, cov_outcome_r = 0.2,
  n_cov_ancova = 3, n_exp = 20, n_nexp = 20
)
}
\references{
Cooper, H., Hedges, L.V., & Valentine, J.C. (Eds.). (2019). The handbook of research synthesis and meta-analysis. Russell Sage Foundation.
}
