% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions_summary.R
\name{as.data.frame.metaConvert}
\alias{as.data.frame.metaConvert}
\title{Convert a \dQuote{metaConvert} object to a dataframe}
\usage{
\method{as.data.frame}{metaConvert}(x, ...)
}
\arguments{
\item{x}{an object of class \dQuote{metaConvert}}

\item{...}{other arguments passed to \code{\link{summary.metaConvert}}}
}
\value{
A dataframe containing the effect size results, diagnostics, and all input data columns.
}
\description{
Convert a \dQuote{metaConvert} object to a dataframe
}
\details{
Convenience wrapper around \code{summary.metaConvert(x, ...)}.
}
\examples{
### get the full output as a dataframe
as.data.frame(convert_df(df.haza, measure = "g"))
}
\seealso{
\code{\link{summary.metaConvert}}
}
