% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{df.haza}
\alias{df.haza}
\title{Meta-analytic dataset inspired from Haza and colleagues (2024)}
\format{
An object of class \code{data.frame} with 170 rows and 106 columns.
}
\source{
Haza B, Gosling CJ, Conty L & Pinabiaux C (2024). Social Functioning in Children and Adolescents with ADHD: A Meta-analysis. Journal of Child Psychology and Psychiatry and Allied Disciplines.
}
\usage{
df.haza
}
\description{
Dataset of a meta-analysis exploring the specificity of social functioning of children with ADHD (compared to healthy controls) in case-control studies.
This dataset contains:
1. several information coming from the same participants (due to the completion of multiple outcomes).
1. several information coming from the same study (due to the presence of multiple subgroups).
1. overlapping information for the same comparison
1. several information types from which a standardized mean difference can be estimated/converted
}
\keyword{datasets}
