% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/functions_summary.R
\name{print.metaConvert}
\alias{print.metaConvert}
\title{Print a summary of an object of class \dQuote{metaConvert}}
\usage{
\method{print}{metaConvert}(x, ...)
}
\arguments{
\item{x}{an object of class \dQuote{metaConvert}}

\item{...}{other arguments that can be passed to the function}
}
\value{
Implicitly calls the \code{\link{summary.metaConvert}} function.
}
\description{
Print a summary of an object of class \dQuote{metaConvert}
}
\details{
Summary method for objects of class \dQuote{metaConvert}.
}
\examples{
### print the results of an object of class metaConvert
convert_df(df.haza, measure = "g")
}
\seealso{
\code{\link{summary.metaConvert}}
}
