% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/es_from_PROP.R
\name{es_from_prop_single_group_counts}
\alias{es_from_prop_single_group_counts}
\title{Convert single-group case counts into a proportion effect size measure}
\usage{
es_from_prop_single_group_counts(
  n_cases,
  n_sample,
  prop_to_es = "raw",
  reverse_prop
)
}
\arguments{
\item{n_cases}{number of cases in the single group}

\item{n_sample}{total sample size}

\item{prop_to_es}{method used to compute the effect size from the proportion.
Must be \code{"raw"} (default), \code{"logit"}, or \code{"freeman_tukey"}.}

\item{reverse_prop}{a logical value indicating whether the direction of the proportion should be flipped.}
}
\value{
This function returns the same output as \code{\link{es_from_prop_single_group}()}.
See that function's documentation for details.
}
\description{
Convert single-group case counts into a proportion effect size measure
}
\details{
This is a convenience function that converts case counts to proportions
and then calls \code{\link{es_from_prop_single_group}()}.

The proportion is calculated as:
\deqn{prop = \frac{n\_cases}{n\_sample}}

Then, calculations of the \code{\link{es_from_prop_single_group}()} are applied.

Rows where \code{n_cases > n_sample} are set to NA (both values) with a
warning; the affected rows return NA, but do not abort the run.
}
\examples{
es_from_prop_single_group_counts(n_cases = 25, n_sample = 100)
}
\references{
Barendregt, J. J., Doi, S. A., Lee, Y. Y., Norman, R. E., & Vos, T. (2013).
Meta-analysis of prevalence. Journal of Epidemiology and Community Health, 67(11), 974-978.
}
