% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/es_from_PAIRED_SINGLE_GROUP.R
\name{es_from_means_sd_pre_post_single_group}
\alias{es_from_means_sd_pre_post_single_group}
\title{Convert pre-post means of a single group into standard effect size measures}
\usage{
es_from_means_sd_pre_post_single_group(
  mean_pre_exp,
  mean_exp,
  mean_pre_sd_exp,
  mean_sd_exp,
  n_exp,
  r_pre_post_exp = 0.8,
  pre_post_to_smd = "bonett",
  smd_to_cor = "viechtbauer",
  reverse_means_pre_post
)
}
\arguments{
\item{mean_pre_exp}{mean of the group at baseline}

\item{mean_exp}{mean of the group at follow up}

\item{mean_pre_sd_exp}{standard deviation of the group at baseline}

\item{mean_sd_exp}{standard deviation of the group at follow up}

\item{n_exp}{number of participants in the group}

\item{r_pre_post_exp}{pre-post correlation within the group}

\item{pre_post_to_smd}{formula used to convert the pre and post means/SD into a SMD (see details).}

\item{smd_to_cor}{formula used to convert the \code{cohen_d} value into a coefficient correlation (see details).}

\item{reverse_means_pre_post}{a logical value indicating whether the direction of generated effect sizes should be flipped.}
}
\value{
This function estimates and converts between several effect size measures.

\tabular{ll}{
\code{natural effect size measure} \tab MDw + Dw + Gw\cr
\tab \cr
\code{converted effect size measure} \tab OR + R + Z \cr
\tab \cr
\code{required input data} \tab See 'Section 15. Paired: pre-post means and dispersion'\cr
\tab https://metaconvert.org/input.html\cr
\tab \cr
}
}
\description{
Convert pre-post means of a single group into standard effect size measures
}
\details{
This function converts pre-post means of a single group into within-group Cohen's d (dw), Hedges' g (gw), and mean difference (mdw).
These within-group effect sizes quantify the standardized change from baseline to follow-up within one group.
Odds ratio (OR) and correlation coefficients (R/Z) are then converted from Cohen's d.

Four formulas can be used to convert the pre/post means into a SMD (\code{pre_post_to_smd} argument):
\enumerate{
\item \code{"bonett"}: baseline SD standardizer (Bonett, 2008; equivalent to the SMCRH measure in metafor)
\deqn{d\_w = \frac{mean\_post\_exp - mean\_pre\_exp}{mean\_pre\_sd\_exp}}
\deqn{var(g\_w) = \frac{sd\_change^2}{sd\_pre^2(n-1)} + \frac{g\_w^2}{2(n-1)}}
where \deqn{sd\_change = \sqrt{sd\_pre^2 + sd\_post^2 - 2r\,sd\_pre\,sd\_post}}
\item \code{"cooper"} (alias: "morris_drm"): raw score standardizer (Cooper 2019, Morris & DeShon 2002)
\deqn{d\_rm = \frac{mean\_post\_exp - mean\_pre\_exp}{sd\_change} * \sqrt{2 * (1 - r\_pre\_post\_exp)}}
\deqn{var(d\_rm) = \frac{2 * (1 - r\_pre\_post\_exp)}{n\_exp} + \frac{d\_rm^2}{2 * n\_exp}}
\item \code{"morris_dz"}: change score standardizer (Morris & DeShon, 2002; equivalent to the SMCC measure in metafor)
\deqn{d\_z = \frac{mean\_post\_exp - mean\_pre\_exp}{sd\_change}}
\deqn{var(g\_z) = \frac{1}{n} + \frac{g\_z^2}{2n}}
\item \code{"morris_dav"}: average SD standardizer (Bonett, 2008; equivalent to the SMCRP measure in metafor)
\deqn{d\_av = \frac{mean\_post\_exp - mean\_pre\_exp}{\sqrt{(mean\_pre\_sd\_exp^2 + mean\_post\_sd\_exp^2)/2}}}
\deqn{g\_av = d\_av \times J(mi), \quad mi = \frac{2(n\_exp - 1)}{1 + r\_pre\_post\_exp^2}}
\deqn{var(g\_av) = J^2 \left[\frac{2(1 - r)}{n} + \frac{d^2(1 + r^2)}{4n}\right]}
}

The within-group Hedges' g is obtained by applying a bias correction factor J to d:
\deqn{g\_w = d\_w * J(n\_exp-1)}

The within-group mean difference is simply:
\deqn{md\_w = mean\_post\_exp - mean\_pre\_exp}
\deqn{var(md\_w) = \frac{sd\_change^2}{n\_exp}}

To estimate other effect size measures,
calculations of the \code{\link{es_from_cohen_d}()} are applied, treating the single group as a matched design.
}
\examples{
es_from_means_sd_pre_post_single_group(
  n_exp = 36,
  mean_pre_exp = 98, mean_exp = 102,
  mean_pre_sd_exp = 16, mean_sd_exp = 17,
  r_pre_post_exp = 0.8
)
}
\references{
Bonett, D. G. (2008). Confidence intervals for standardized linear contrasts of means. Psychological Methods, 13(2), 99-109.

Morris, S. B. (2008). Estimating effect sizes from pretest-posttest-control group designs. Organizational Research Methods, 11(2), 364-386. https://doi.org/10.1177/1094428106291059

Cooper, H., Hedges, L.V., & Valentine, J.C. (Eds.). (2019). The handbook of research synthesis and meta-analysis. Russell Sage Foundation.

Morris, S. B., & DeShon, R. P. (2002). Combining effect size estimates in meta-analysis with repeated measures and independent-groups designs. Psychological Methods, 7(1), 105-125. https://doi.org/10.1037/1082-989X.7.1.105
}
