% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/es_from_PAIRED_SINGLE_GROUP.R
\name{es_from_means_ci_pre_post_single_group}
\alias{es_from_means_ci_pre_post_single_group}
\title{Convert pre-post means and 95\% CI of a single group into standard effect size measures}
\usage{
es_from_means_ci_pre_post_single_group(
  mean_pre_exp,
  mean_exp,
  mean_pre_ci_lo_exp,
  mean_pre_ci_up_exp,
  mean_ci_lo_exp,
  mean_ci_up_exp,
  n_exp,
  r_pre_post_exp = 0.8,
  pre_post_to_smd = "bonett",
  smd_to_cor = "viechtbauer",
  max_asymmetry = 10,
  reverse_means_pre_post
)
}
\arguments{
\item{mean_pre_exp}{mean of the group at baseline}

\item{mean_exp}{mean of the group at follow up}

\item{mean_pre_ci_lo_exp}{lower bound of the 95\% CI of the mean at baseline}

\item{mean_pre_ci_up_exp}{upper bound of the 95\% CI of the mean at baseline}

\item{mean_ci_lo_exp}{lower bound of the 95\% CI of the mean at follow up}

\item{mean_ci_up_exp}{upper bound of the 95\% CI of the mean at follow up}

\item{n_exp}{number of participants in the group}

\item{r_pre_post_exp}{pre-post correlation within the group}

\item{pre_post_to_smd}{formula used to convert the pre and post means/SD into a SMD (see details).}

\item{smd_to_cor}{formula used to convert the \code{cohen_d} value into a coefficient correlation (see details).}

\item{max_asymmetry}{percentage indicating the tolerance before detecting asymmetry in the 95\% CI bounds.}

\item{reverse_means_pre_post}{a logical value indicating whether the direction of generated effect sizes should be flipped.}
}
\value{
This function estimates and converts between several effect size measures.

\tabular{ll}{
\code{natural effect size measure} \tab MDw + Dw + Gw\cr
\tab \cr
\code{converted effect size measure} \tab OR + R + Z \cr
\tab \cr
\code{required input data} \tab See 'Section 15. Paired: pre-post means and dispersion'\cr
\tab https://metaconvert.org/input.html\cr
\tab \cr
}
}
\description{
Convert pre-post means and 95\% CI of a single group into standard effect size measures
}
\details{
This function converts the bounds of the 95\% CI of the pre/post means of a single group into standard errors (Section 6.3.1 in the Cochrane Handbook).
\deqn{mean\_pre\_se\_exp = \frac{mean\_pre\_ci\_up\_exp - mean\_pre\_ci\_lo\_exp}{2 * qt{(0.975, df = n\_exp - 1)}}}
\deqn{mean\_post\_se\_exp = \frac{mean\_post\_ci\_up\_exp - mean\_post\_ci\_lo\_exp}{2 * qt{(0.975, df = n\_exp - 1)}}}

Then, calculations of the \code{\link{es_from_means_se_pre_post_single_group}()} are applied.
}
\examples{
es_from_means_ci_pre_post_single_group(
  n_exp = 36,
  mean_pre_exp = 98,
  mean_pre_ci_lo_exp = 88, mean_pre_ci_up_exp = 108,
  mean_exp = 102,
  mean_ci_lo_exp = 92, mean_ci_up_exp = 112,
  r_pre_post_exp = 0.8
)
}
\references{
Higgins JPT, Li T, Deeks JJ (editors). Chapter 6: Choosing effect size measures and computing estimates of effect. In: Higgins JPT, Thomas J, Chandler J, Cumpston M, Li T, Page MJ, Welch VA (editors). Cochrane Handbook for Systematic Reviews of Interventions version 6.3 (updated February 2022). Cochrane, 2022.

Bonett, D. G. (2008). Confidence intervals for standardized linear contrasts of means. Psychological Methods, 13(2), 99-109.

Morris, S. B. (2008). Estimating effect sizes from pretest-posttest-control group designs. Organizational Research Methods, 11(2), 364-386.

Cooper, H., Hedges, L.V., & Valentine, J.C. (Eds.). (2019). The handbook of research synthesis and meta-analysis. Russell Sage Foundation.
}
