% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/es_from_stand_RD.R
\name{es_from_rd_pval}
\alias{es_from_rd_pval}
\title{Convert a risk difference value and its p-value to several effect size measures}
\usage{
es_from_rd_pval(
  rd,
  rd_pval,
  baseline_risk,
  n_exp,
  n_nexp,
  n_cases,
  n_controls,
  n_sample,
  reverse_rd_pval
)
}
\arguments{
\item{rd}{risk difference value}

\item{rd_pval}{p-value of the risk difference}

\item{baseline_risk}{proportion of cases in the non-exposed/control group}

\item{n_exp}{number of participants in the exposed/treatment group}

\item{n_nexp}{number of participants in the non-exposed/control group}

\item{n_cases}{number of cases/events across both groups}

\item{n_controls}{number of controls/no-event across both groups}

\item{n_sample}{total number of participants in the sample}

\item{reverse_rd_pval}{a logical value indicating whether the direction of the generated effect sizes should be flipped.}
}
\value{
This function estimates and converts between several effect size measures.

\tabular{ll}{
\code{natural effect size measure} \tab RD\cr
\tab \cr
\code{converted effect size measure} \tab OR + RR + NNT\cr
\tab \cr
\code{required input data} \tab rd + rd_pval\cr
\tab \cr
}
}
\description{
Convert a risk difference value and its p-value to several effect size measures
}
\details{
This function uses the p-value of the risk difference to obtain the standard error
(Section 6.3.2 in the Cochrane Handbook):
\deqn{z = qnorm(rd\_pval / 2, lower.tail = FALSE)}
\deqn{rd\_se = |\frac{rd}{z}|}

Then, calculations of \code{\link{es_from_rd_se}()} are applied.
}
\examples{
es_from_rd_pval(
  rd = 0.15, rd_pval = 0.01,
  baseline_risk = 0.30, n_exp = 100, n_nexp = 100
)
}
\references{
Higgins, J. P., Thomas, J., Chandler, J., Cumpston, M., Li, T., Page, M. J., & Welch, V. A. (Eds.). (2019). Cochrane handbook for systematic reviews of interventions. John Wiley & Sons.
}
