% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{df.short}
\alias{df.short}
\title{Short version of the df.haza dataset}
\format{
An object of class \code{grouped_df} (inherits from \code{tbl_df}, \code{tbl}, \code{data.frame}) with 37 rows and 109 columns.
}
\source{
Haza B, Gosling CJ, Conty L & Pinabiaux C (2024). Social Functioning in Children and Adolescents with ADHD: A Meta-analysis. Journal of Child Psychology and Psychiatry and Allied Disciplines.
}
\usage{
df.short
}
\description{
This dataset is a shoter version of the \code{\link{df.haza}} dataset.
}
\keyword{datasets}
