% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/es_from_PAIRED_SINGLE_GROUP.R
\name{es_from_mean_change_ci_single_group}
\alias{es_from_mean_change_ci_single_group}
\title{Convert mean change and 95\% CI of a single group into standard effect size measures}
\usage{
es_from_mean_change_ci_single_group(
  mean_change_exp,
  mean_change_ci_lo_exp,
  mean_change_ci_up_exp,
  n_exp,
  r_pre_post_exp = 0.8,
  max_asymmetry = 10,
  smd_to_cor = "viechtbauer",
  pre_post_to_smd = "cooper",
  reverse_mean_change
)
}
\arguments{
\item{mean_change_exp}{mean change of participants in the group.}

\item{mean_change_ci_lo_exp}{lower bound of the 95\% CI around the mean change.}

\item{mean_change_ci_up_exp}{upper bound of the 95\% CI around the mean change.}

\item{n_exp}{number of participants in the group.}

\item{r_pre_post_exp}{pre-post correlation within the group}

\item{max_asymmetry}{percentage indicating the tolerance before detecting asymmetry in the 95\% CI bounds.}

\item{smd_to_cor}{formula used to convert the \code{cohen_d} value into a coefficient correlation (see details).}

\item{pre_post_to_smd}{formula used to convert the mean change into a SMD (\code{"cooper"} by default; \code{"morris_dz"} also accepted, see details).}

\item{reverse_mean_change}{a logical value indicating whether the direction of generated effect sizes should be flipped.}
}
\value{
This function estimates and converts between several effect size measures.

\tabular{ll}{
\code{natural effect size measure} \tab MDw + Dw + Gw\cr
\tab \cr
\code{converted effect size measure} \tab OR + R + Z \cr
\tab \cr
\code{required input data} \tab See 'Section 14. Paired: mean change, and dispersion'\cr
\tab https://metaconvert.org/input.html\cr
\tab \cr
}
}
\description{
Convert mean change and 95\% CI of a single group into standard effect size measures
}
\details{
This function converts the mean change and 95\% CI of a single group
into within-group Cohen's d, Hedges' g, and mean difference. The effect sizes are then converted to other measures.

The effect size (d_rm) depends linearly on the pre-post correlation (0.8 assumed when
\code{r_pre_post_exp} is missing); see \code{\link{es_from_mean_change_sd_single_group}}.

This function simply internally calls the \code{\link{es_from_means_ci_pre_post_single_group}} function but setting:
\deqn{mean\_pre\_exp = 0}
\deqn{mean\_pre\_ci\_lo\_exp = 0}
\deqn{mean\_pre\_ci\_up\_exp = 0}
\deqn{mean\_exp = mean\_change\_exp}
\deqn{mean\_ci\_lo\_exp = mean\_change\_ci\_lo\_exp}
\deqn{mean\_ci\_up\_exp = mean\_change\_ci\_up\_exp}

To know more about the calculations, see \code{\link{es_from_means_sd_pre_post_single_group}} function.
}
\examples{
es_from_mean_change_ci_single_group(
  n_exp = 36,
  mean_change_exp = 8.4,
  mean_change_ci_lo_exp = 6.4, mean_change_ci_up_exp = 10.4,
  r_pre_post_exp = 0.2
)
}
\references{
Bonett, D. G. (2008). Confidence intervals for standardized linear contrasts of means. Psychological Methods, 13(2), 99-109.

Morris, S. B. (2008). Estimating effect sizes from pretest-posttest-control group designs. Organizational Research Methods, 11(2), 364-386.

Cooper, H., Hedges, L.V., & Valentine, J.C. (Eds.). (2019). The handbook of research synthesis and meta-analysis. Russell Sage Foundation.
}
