% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/es_from_REGRESSION.R
\name{es_from_linreg_b_ci}
\alias{es_from_linreg_b_ci}
\title{Convert an unstandardized regression coefficient and its confidence interval
into several effect size measures}
\usage{
es_from_linreg_b_ci(
  linreg_b,
  linreg_b_ci_lo,
  linreg_b_ci_up,
  n_sample,
  n_covariates,
  sd_iv,
  unit_increase_iv,
  unit_type = "raw_scale",
  n_exp,
  n_nexp,
  cor_to_smd = "viechtbauer",
  reverse_linreg_b
)
}
\arguments{
\item{linreg_b}{unstandardized regression coefficient from a linear regression model}

\item{linreg_b_ci_lo}{lower bound of the 95\% confidence interval of the regression coefficient}

\item{linreg_b_ci_up}{upper bound of the 95\% confidence interval of the regression coefficient}

\item{n_sample}{the total number of participants}

\item{n_covariates}{the number of covariates in the model (excluding the predictor of interest).}

\item{sd_iv}{the standard deviation of the independent variable (optional, see details)}

\item{unit_increase_iv}{a value of the independent variable that will be used to estimate the Cohen's d (optional, see details).}

\item{unit_type}{the type of unit for the \code{unit_increase_iv} argument. Must be either "sd" or "raw_scale"}

\item{n_exp}{number of the experimental/exposed group (optional)}

\item{n_nexp}{number of the non-experimental/non-exposed group (optional)}

\item{cor_to_smd}{formula used to convert a \code{pearson_r} or \code{fisher_z} value into a SMD.}

\item{reverse_linreg_b}{a logical value indicating whether the direction of the generated effect sizes should be flipped.}
}
\value{
This function estimates and converts between several effect size measures.
\tabular{ll}{
\code{natural effect size measure} \tab Rp (partial correlation) + Zp (Fisher's z of partial r)\cr
\tab \cr
\code{converted effect size measure} \tab D + G + OR (approximate, see \code{\link{es_from_linreg_t}})\cr
}
}
\description{
Convert an unstandardized regression coefficient and its confidence interval
into several effect size measures
}
\details{
This function derives the standard error from the 95\% confidence interval using a
t-distribution with \eqn{df = n\_sample - n\_covariates - 2} degrees of freedom:
\deqn{SE(b) = \frac{ci\_up - ci\_lo}{2 \times qt(.975, df)}}

Then, calculations of the \code{\link{es_from_linreg_b_se}} function are applied.
For binary predictors without covariates, use \code{\link{es_from_beta_unstd}} instead.
}
\examples{
es_from_linreg_b_ci(
  linreg_b = 1.5, linreg_b_ci_lo = 0.3, linreg_b_ci_up = 2.7,
  n_sample = 100, n_covariates = 2
)
}
\references{
Aloe, A. M., & Thompson, C. G. (2013). The synthesis of partial effect sizes.
\emph{Journal of the Society for Social Work and Research}, 4(4), 390--405.
}
