% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/es_from_PAIRED_SINGLE_GROUP.R
\name{es_from_paired_t_single_group}
\alias{es_from_paired_t_single_group}
\title{Convert paired t-test statistic from a single group into standard effect size measures}
\usage{
es_from_paired_t_single_group(
  paired_t_exp,
  n_exp,
  r_pre_post_exp = 0.8,
  smd_to_cor = "viechtbauer",
  pre_post_to_smd = "cooper",
  reverse_paired_t
)
}
\arguments{
\item{paired_t_exp}{paired t-test statistic (pre-post comparison) for the group.}

\item{n_exp}{number of participants in the group.}

\item{r_pre_post_exp}{pre-post correlation within the group}

\item{smd_to_cor}{formula used to convert the \code{cohen_d} value into a coefficient correlation (see details).}

\item{pre_post_to_smd}{formula used to convert the paired t statistic into a SMD (\code{"cooper"} by default; \code{"morris_dz"} also accepted, see details).}

\item{reverse_paired_t}{a logical value indicating whether the direction of generated effect sizes should be flipped.}
}
\value{
This function estimates and converts between several effect size measures.

\tabular{ll}{
\code{natural effect size measure} \tab MDw + Dw + Gw\cr
\tab \cr
\code{converted effect size measure} \tab OR + R + Z \cr
\tab \cr
\code{required input data} \tab See 'Section 15. Paired: pre-post paired t-test'\cr
\tab https://metaconvert.org/input.html\cr
\tab \cr
}
}
\description{
Convert paired t-test statistic from a single group into standard effect size measures
}
\details{
This function converts a paired t-test statistic from a single group
into within-group Cohen's d, Hedges' g, and mean difference using the raw score standardizer (morris_drm/cooper).

The paired t-test statistic is related to the mean difference and standard error of difference:
\deqn{t\_paired = \frac{mean\_diff}{SE\_diff}}

where:
\deqn{SE\_diff = \frac{SD\_diff}{\sqrt{n}}}
\deqn{SD\_diff = \sqrt{SD\_pre^2 + SD\_post^2 - 2 \times r \times SD\_pre \times SD\_post}}

This function calculates the raw score standardized mean difference (d_rm, Morris & DeShon 2002):
\deqn{d\_rm = t\_paired \times \sqrt{\frac{2 \times (1 - r)}{n}}}

The variance is calculated as:
\deqn{var(d\_rm) = \frac{2 \times (1 - r)}{n} + \frac{d\_rm^2}{2 \times n}}

The result depends on the pre-post correlation (0.8 assumed when \code{r_pre_post_exp}
is missing); see \code{\link{es_from_mean_change_sd_single_group}}.

The within-group Hedges' g is obtained by applying a bias correction factor J to d.

To estimate other effect size measures, calculations of the \code{\link{es_from_cohen_d}()} are applied.
}
\examples{
es_from_paired_t_single_group(
  paired_t_exp = 2.5,
  n_exp = 20,
  r_pre_post_exp = 0.7
)
}
\references{
Morris, S. B., & DeShon, R. P. (2002). Combining effect size estimates in meta-analysis with repeated measures and independent-groups designs. Psychological Methods, 7(1), 105-125.

Cooper, H., Hedges, L.V., & Valentine, J.C. (Eds.). (2019). The handbook of research synthesis and meta-analysis. Russell Sage Foundation.
}
