% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{df.compare1}
\alias{df.compare1}
\title{Fictitious dataset 1}
\format{
An object of class \code{data.frame} with 5 rows and 7 columns.
}
\usage{
df.compare1
}
\description{
First fictitious dataset aiming to understand how the \code{\link{compare_df}} function works.
Slightly different from \code{\link{df.compare1}}
}
\keyword{datasets}
