% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/es_from_stand_RD.R
\name{es_from_rd_ci}
\alias{es_from_rd_ci}
\title{Convert a risk difference value and its 95\% confidence interval to several effect size measures}
\usage{
es_from_rd_ci(
  rd,
  rd_ci_lo,
  rd_ci_up,
  baseline_risk,
  n_exp,
  n_nexp,
  n_cases,
  n_controls,
  n_sample,
  reverse_rd
)
}
\arguments{
\item{rd}{risk difference value}

\item{rd_ci_lo}{lower bound of the 95\% CI around the risk difference}

\item{rd_ci_up}{upper bound of the 95\% CI around the risk difference}

\item{baseline_risk}{proportion of cases in the non-exposed/control group}

\item{n_exp}{number of participants in the exposed/treatment group}

\item{n_nexp}{number of participants in the non-exposed/control group}

\item{n_cases}{number of cases/events across both groups}

\item{n_controls}{number of controls/no-event across both groups}

\item{n_sample}{total number of participants in the sample}

\item{reverse_rd}{a logical value indicating whether the direction of the generated effect sizes should be flipped.}
}
\value{
This function estimates and converts between several effect size measures.

\tabular{ll}{
\code{natural effect size measure} \tab RD\cr
\tab \cr
\code{converted effect size measure} \tab OR + RR + NNT\cr
\tab \cr
\code{required input data} \tab rd + rd_ci_lo + rd_ci_up\cr
\tab \cr
}
}
\description{
Convert a risk difference value and its 95\% confidence interval to several effect size measures
}
\details{
This function computes the standard error of the risk difference from its 95\% CI
(Section 6.5.2.2 in the Cochrane Handbook):
\deqn{rd\_se = \frac{rd\_ci\_up - rd\_ci\_lo}{2 \times qnorm(.975)}}

Then, calculations of \code{\link{es_from_rd_se}()} are applied.
}
\examples{
es_from_rd_ci(
  rd = 0.15, rd_ci_lo = 0.05, rd_ci_up = 0.25,
  baseline_risk = 0.30, n_exp = 100, n_nexp = 100
)
}
\references{
Higgins JPT, Li T, Deeks JJ (editors). Chapter 6: Choosing effect size measures and computing estimates of effect. In: Higgins JPT, Thomas J, Chandler J, Cumpston M, Li T, Page MJ, Welch VA (editors). Cochrane Handbook for Systematic Reviews of Interventions version 6.3 (updated February 2022). Cochrane, 2022. Available from www.training.cochrane.org/handbook.
}
